==> isis-fish-4.2.0.1-sources.jar: fr/ifremer/isisfish/ui/input/tree/FisheryTreeNode.java <==
/*
 * #%L
 * $Id: FisheryTreeNode.java 3226 2011-04-01 10:15:46Z chatellier $
 * $HeadURL: http://svn.forge.codelutin.com/svn/isis-fish/tags/isis-fish-4.2.0.1/src/main/java/fr/ifremer/isisfish/ui/input/tree/FisheryTreeNode.java $
 * %%
 * Copyright (C) 2011 Ifremer, Codelutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui.input.tree;

import jaxx.runtime.swing.nav.tree.NavTreeNode;
import jaxx.runtime.swing.nav.tree.NavTreeNodeChildLoador;

/**
 * Do nothing, just to type strange template.
 * 
 * @author chatellier
 * @version $Revision: 3226 $
 * @since 3.4.0.0
 * 
 * Last update : $Date: 2011-04-01 12:15:46 +0200 (Fri, 01 Apr 2011) $
 * By : $Author: chatellier $
 */
public class FisheryTreeNode extends NavTreeNode<FisheryTreeNode> {
    
    /** serialVersionUID. */
    private static final long serialVersionUID = -3813351863284748776L;

    /**
     * Constructor.
     * 
     * @param internalClass
     * @param id
     * @param context
     * @param childLoador
     */
    public FisheryTreeNode(Class<?> internalClass, String id, String context,
            NavTreeNodeChildLoador<?, ?, FisheryTreeNode> childLoador) {
        super(internalClass, id, context, childLoador);
    }
}

==> isis-fish-4.3.0.0-sources.jar: fr/ifremer/isisfish/ui/input/tree/FisheryTreeNode.java <==
/*
 * #%L
 * $Id: FisheryTreeNode.java 3798 2012-10-30 10:39:32Z echatellier $
 * $HeadURL: https://svn.codelutin.com/isis-fish/tags/isis-fish-4.3.0.0/src/main/java/fr/ifremer/isisfish/ui/input/tree/FisheryTreeNode.java $
 * %%
 * Copyright (C) 2011 Ifremer, Codelutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui.input.tree;

import jaxx.runtime.swing.nav.tree.NavTreeNode;
import jaxx.runtime.swing.nav.tree.NavTreeNodeChildLoador;

/**
 * Do nothing, just to type strange template.
 * 
 * @author chatellier
 * @version $Revision: 3798 $
 * @since 3.4.0.0
 * 
 * Last update : $Date: 2012-10-30 11:39:32 +0100 (Tue, 30 Oct 2012) $
 * By : $Author: echatellier $
 */
public class FisheryTreeNode extends NavTreeNode<FisheryTreeNode> {
    
    /** serialVersionUID. */
    private static final long serialVersionUID = -3813351863284748776L;

    /**
     * Constructor.
     * 
     * @param internalClass
     * @param id
     * @param context
     * @param childLoador
     */
    public FisheryTreeNode(Class<?> internalClass, String id, String context,
            NavTreeNodeChildLoador<?, ?, FisheryTreeNode> childLoador) {
        super(internalClass, id, context, childLoador);
    }
}
